aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAris Adamantiadis <aris@0xbadc0de.be>2009-09-26 01:34:14 +0200
committerAris Adamantiadis <aris@0xbadc0de.be>2009-09-26 01:34:14 +0200
commit0f77578ee2095311ebe71785be4ee7dad135728a (patch)
tree1adbaba9565175753d2d05aef9321808f99a836a
parent3e314e863cb70f8594b0c9b79d14edb3a929d708 (diff)
downloadlibssh-0f77578ee2095311ebe71785be4ee7dad135728a.tar.gz
libssh-0f77578ee2095311ebe71785be4ee7dad135728a.tar.xz
libssh-0f77578ee2095311ebe71785be4ee7dad135728a.zip
Fixed doxygen compilation warnings
-rw-r--r--include/libssh/sftp.h2
-rw-r--r--libssh/channels.c6
-rw-r--r--libssh/dh.c2
-rw-r--r--libssh/error.c6
-rw-r--r--libssh/keyfiles.c2
-rw-r--r--libssh/options.c4
-rw-r--r--libssh/string.c4
7 files changed, 13 insertions, 13 deletions
diff --git a/include/libssh/sftp.h b/include/libssh/sftp.h
index 3bb242b2..1c4a2ab5 100644
--- a/include/libssh/sftp.h
+++ b/include/libssh/sftp.h
@@ -418,7 +418,7 @@ LIBSSH_API int sftp_file_close(SFTP_FILE *file) SFTP_DEPRECATED;
* @return A sftp file handle, NULL on error with ssh and sftp
* error set.
*/
-LIBSSH_API SFTP_FILE *sftp_open(SFTP_SESSION *session, const char *file, int flags,
+LIBSSH_API SFTP_FILE *sftp_open(SFTP_SESSION *session, const char *file, int access,
mode_t mode);
LIBSSH_API void sftp_file_set_nonblocking(SFTP_FILE *handle);
diff --git a/libssh/dh.c b/libssh/dh.c
index abb07629..1f1b20b9 100644
--- a/libssh/dh.c
+++ b/libssh/dh.c
@@ -856,8 +856,6 @@ int ssh_get_pubkey_hash(ssh_session session, unsigned char **hash) {
return MD5_DIGEST_LEN;
}
-/** \addtogroup ssh_session
- * @{ */
/**
* @brief Deallocate the hash obtained by ssh_get_pubkey_hash.
* This is required under Microsoft platform as this library might use a
diff --git a/libssh/error.c b/libssh/error.c
index 922a7f4a..392e7414 100644
--- a/libssh/error.c
+++ b/libssh/error.c
@@ -76,13 +76,13 @@ const char *ssh_get_error(void *error) {
*
* @param error The SSH session pointer.
*
- * \return SSH_NO_ERROR No error occured\n
+ * \return SSH_NO_ERROR No error occurred\n
* SSH_REQUEST_DENIED The last request was denied but situation is
* recoverable\n
- * SSH_FATAL A fatal error occured. This could be an unexpected
+ * SSH_FATAL A fatal error occurred. This could be an unexpected
* disconnection\n
*
- * \nOther error codes are internal but can be considered same than
+ * Other error codes are internal but can be considered same than
* SSH_FATAL.
*/
int ssh_get_error_code(void *error) {
diff --git a/libssh/keyfiles.c b/libssh/keyfiles.c
index 193fd115..372093a5 100644
--- a/libssh/keyfiles.c
+++ b/libssh/keyfiles.c
@@ -865,7 +865,7 @@ void privatekey_free(ssh_private_key prv) {
/** \brief Retrieve a public key from a file
* \param session the SSH session
* \param filename Filename of the key
- * \param _type Pointer to a integer. If it is not null, it contains the type of the key after execution.
+ * \param type Pointer to a integer. If it is not null, it contains the type of the key after execution.
* \return a SSH String containing the public key, or NULL if it failed.
* \see string_free()
* \see publickey_from_privatekey()
diff --git a/libssh/options.c b/libssh/options.c
index d7502e64..3a6ec61f 100644
--- a/libssh/options.c
+++ b/libssh/options.c
@@ -997,7 +997,9 @@ int ssh_options_allow_ssh2(ssh_options opt, int allow) {
*
* @param opt The options structure to use.
*
- * @param callback A callback function for the printing.
+ * @param cb A callback function for the printing.
+ *
+ * @param userdata Pointer to user-provided data
*
* @return 0 on success, < 0 on error.
*
diff --git a/libssh/string.c b/libssh/string.c
index d06fab63..2299440a 100644
--- a/libssh/string.c
+++ b/libssh/string.c
@@ -96,7 +96,7 @@ struct ssh_string_struct *string_from_char(const char *what) {
/**
* \brief returns the size of a SSH string
- * \param str the input SSH string
+ * \param s the input SSH string
* \return size of the content of str, 0 on error
*/
size_t string_len(struct ssh_string_struct *s) {
@@ -109,7 +109,7 @@ size_t string_len(struct ssh_string_struct *s) {
/**
* \brief convert a SSH string to a C nul-terminated string
- * \param str the input SSH string
+ * \param s the input SSH string
* \return a malloc'ed string pointer.
* \warning If the input SSH string contains zeroes, some parts of
* the output string may not be readable with regular libc functions.
diff --git a/libssh/channels.c b/libssh/channels.c
index f96051ef..1f2c64c5 100644
--- a/libssh/channels.c
+++ b/libssh/channels.c
@@ -1229,13 +1229,13 @@ int channel_request_shell(ssh_channel channel) {
*
* @param channel The channel to send the request.
*
* @param system The subsystem to request (for example "sftp").
*
* @return SSH_SUCCESS on success, SSH_ERROR on error.
*
* @warning You normally don't have to call it for sftp, see sftp_new().
*/
-int channel_request_subsystem(ssh_channel channel, const char *sys) {
+int channel_request_subsystem(ssh_channel channel, const char *subsys) {
ssh_buffer buffer = NULL;
ssh_string subsystem = NULL;
int rc = SSH_ERROR;
@@ -1245,7 +1245,7 @@ int channel_request_subsystem(ssh_channel channel, const char *sys) {
goto error;
}
- subsystem = string_from_char(sys);
+ subsystem = string_from_char(subsys);
if (subsystem == NULL) {
goto error;
}
@@ -1229,13 +1229,13 @@ int channel_request_shell(ssh_channel channel) {
* @param channel The channel to send the request.
*
- * @param system The subsystem to request (for example "sftp").
+ * @param subsys The subsystem to request (for example "sftp").
*
* @return SSH_SUCCESS on success, SSH_ERROR on error.